sensor

package
v0.9.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 31, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AlertImmediateOperation

type AlertImmediateOperation uint8
const (
	AlertImmediateOperationInitiateAlert AlertImmediateOperation = 0b00
	AlertImmediateOperationGetStatus     AlertImmediateOperation = 0b01
	AlertImmediateOperationClearStatus   AlertImmediateOperation = 0b10
	AlertImmediateOperationReserved      AlertImmediateOperation = 0b11
)

type AlertImmediateRequest

type AlertImmediateRequest struct {
	ChannelNumber uint8

	DestinationSelector uint8
	Operation           uint8

	SendAlertString     bool
	AlertStringSelector uint8

	GeneratorID  uint8
	EvMRev       uint8
	SensorType   types.SensorType
	SensorNumber types.SensorNumber

	EventDir         types.EventDir
	EventReadingType types.EventReadingType
	EventData        types.EventData
}

30.7 Alert Immediate Command

func (*AlertImmediateRequest) Command

func (req *AlertImmediateRequest) Command() types.Command

func (*AlertImmediateRequest) Pack

func (req *AlertImmediateRequest) Pack() []byte

type AlertImmediateResponse

type AlertImmediateResponse struct {
	AlertImmediateStatus uint8
}

func (*AlertImmediateResponse) Format

func (res *AlertImmediateResponse) Format() string

func (*AlertImmediateResponse) Unpack

func (res *AlertImmediateResponse) Unpack(msg []byte) error

type AlertImmediateStatus

type AlertImmediateStatus uint8
const (
	AlertImmediateStatusNoStatus      AlertImmediateStatus = 0x00
	AlertImmediateStatusNormalEnd     AlertImmediateStatus = 0x01
	AlertImmediateStatusFailedRetry   AlertImmediateStatus = 0x02
	AlertImmediateStatusFailedWaitACK AlertImmediateStatus = 0x03
	AlertImmediateStatusInProgress    AlertImmediateStatus = 0xff
)

type ArmPEFPostponeTimerRequest

type ArmPEFPostponeTimerRequest struct {
	// PEF Postpone Timeout, in seconds. 01h -> 1 second.
	//
	//  00h = disable Postpone Timer (PEF will immediately handle events, if enabled).
	//        The BMC automatically disables the timer whenever the system
	//        enters a sleep state, is powered down, or reset.
	//  01h - FDh = arm timer.
	//        Timer will automatically start counting down from given value
	//        when the last-processed event Record ID is not equal to the last
	//        received event's Record ID.
	//  FEh = Temporary PEF disable.
	//        The PEF Postpone timer does not countdown from the value.
	//        The BMC automatically re-enables PEF (if enabled in the PEF configuration parameters)
	//        and sets the PEF Postpone timeout to 00h whenever the system
	//        enters a sleep state, is powered down, or reset. Software can
	//        cancel this disable by setting this parameter to 00h or 01h-FDh.
	//  FFh = get present countdown value
	Timeout uint8
}

30.2 Arm PEF Postpone Timer Command

func (*ArmPEFPostponeTimerRequest) Command

func (req *ArmPEFPostponeTimerRequest) Command() types.Command

func (*ArmPEFPostponeTimerRequest) Pack

func (req *ArmPEFPostponeTimerRequest) Pack() []byte

type ArmPEFPostponeTimerResponse

type ArmPEFPostponeTimerResponse struct {
	// Present timer countdown value
	PresentValue uint8
}

func (*ArmPEFPostponeTimerResponse) Format

func (res *ArmPEFPostponeTimerResponse) Format() string

func (*ArmPEFPostponeTimerResponse) Unpack

func (res *ArmPEFPostponeTimerResponse) Unpack(msg []byte) error

type ClearMessageFlagsRequest

type ClearMessageFlagsRequest struct {
	ClearOEM2                            bool
	ClearOEM1                            bool
	ClearOEM0                            bool
	ClearWatchdogPreTimeoutInterruptFlag bool
	ClearEventMessageBuffer              bool
	ClearReceiveMessageQueue             bool
}

func (*ClearMessageFlagsRequest) Command

func (req *ClearMessageFlagsRequest) Command() types.Command

func (*ClearMessageFlagsRequest) Pack

func (req *ClearMessageFlagsRequest) Pack() []byte

type ClearMessageFlagsResponse

type ClearMessageFlagsResponse struct {
}

func (*ClearMessageFlagsResponse) Format

func (res *ClearMessageFlagsResponse) Format() string

func (*ClearMessageFlagsResponse) Unpack

func (res *ClearMessageFlagsResponse) Unpack(msg []byte) error

type GetBMCGlobalEnablesRequest

type GetBMCGlobalEnablesRequest struct {
}

func (*GetBMCGlobalEnablesRequest) Command

func (req *GetBMCGlobalEnablesRequest) Command() types.Command

func (*GetBMCGlobalEnablesRequest) Pack

func (req *GetBMCGlobalEnablesRequest) Pack() []byte

type GetBMCGlobalEnablesResponse

type GetBMCGlobalEnablesResponse struct {
	OEM2Enabled bool
	OEM1Enabled bool
	OEM0Enabled bool

	SystemEventLoggingEnabled              bool
	EventMessageBufferEnabled              bool
	EventMessageBufferFullInterruptEnabled bool
	ReceiveMessageQueueInterruptEnabled    bool
}

func (*GetBMCGlobalEnablesResponse) Format

func (res *GetBMCGlobalEnablesResponse) Format() string

func (*GetBMCGlobalEnablesResponse) Unpack

func (res *GetBMCGlobalEnablesResponse) Unpack(msg []byte) error

type GetEventReceiverRequest

type GetEventReceiverRequest struct {
}

func (*GetEventReceiverRequest) Command

func (req *GetEventReceiverRequest) Command() types.Command

func (*GetEventReceiverRequest) Pack

func (req *GetEventReceiverRequest) Pack() []byte

type GetEventReceiverResponse

type GetEventReceiverResponse struct {
	SlaveAddress uint8
	LUN          uint8
}

func (*GetEventReceiverResponse) Format

func (res *GetEventReceiverResponse) Format() string

func (*GetEventReceiverResponse) Unpack

func (res *GetEventReceiverResponse) Unpack(msg []byte) error

type GetLastProcessedEventIdRequest

type GetLastProcessedEventIdRequest struct {
}

30.6 Get Last Processed Event ID Command

func (*GetLastProcessedEventIdRequest) Command

func (*GetLastProcessedEventIdRequest) Pack

func (req *GetLastProcessedEventIdRequest) Pack() []byte

type GetLastProcessedEventIdResponse

type GetLastProcessedEventIdResponse struct {
	MostRecentAdditionTime             time.Time
	LastRecordID                       uint16 // Record ID for last record in SEL. Returns FFFFh if SEL is empty.
	LastSoftwareProcessedEventRecordID uint16
	LastBMCProcessedEventRecordID      uint16 // Returns 0000h when event has been processed but could not be logged because the SEL is full or logging has been disabled.
}

func (*GetLastProcessedEventIdResponse) Format

func (*GetLastProcessedEventIdResponse) Unpack

func (res *GetLastProcessedEventIdResponse) Unpack(msg []byte) error

type GetMessageFlagsRequest

type GetMessageFlagsRequest struct {
}

func (*GetMessageFlagsRequest) Command

func (req *GetMessageFlagsRequest) Command() types.Command

func (*GetMessageFlagsRequest) Pack

func (req *GetMessageFlagsRequest) Pack() []byte

type GetMessageFlagsResponse

type GetMessageFlagsResponse struct {
	OEM2Available                       bool
	OEM1Available                       bool
	OEM0Available                       bool
	WatchdogPreTimeoutInterruptOccurred bool
	EventMessageBufferFull              bool
	ReceiveMessageQueueAvailable        bool // One or more messages ready for reading from Receive Message Queue
}

func (*GetMessageFlagsResponse) Format

func (res *GetMessageFlagsResponse) Format() string

func (*GetMessageFlagsResponse) Unpack

func (res *GetMessageFlagsResponse) Unpack(msg []byte) error

type GetMessageRequest

type GetMessageRequest struct {
}

func (*GetMessageRequest) Command

func (req *GetMessageRequest) Command() types.Command

func (*GetMessageRequest) Pack

func (req *GetMessageRequest) Pack() []byte

type GetMessageResponse

type GetMessageResponse struct {
	ChannelNumber uint8
	MessageData   []byte
}

func (*GetMessageResponse) Format

func (res *GetMessageResponse) Format() string

func (*GetMessageResponse) Unpack

func (res *GetMessageResponse) Unpack(msg []byte) error

type GetPEFCapabilitiesRequest

type GetPEFCapabilitiesRequest struct {
}

30.1 Get PEF Capabilities Command

func (*GetPEFCapabilitiesRequest) Command

func (req *GetPEFCapabilitiesRequest) Command() types.Command

func (*GetPEFCapabilitiesRequest) Pack

func (req *GetPEFCapabilitiesRequest) Pack() []byte

type GetPEFCapabilitiesResponse

type GetPEFCapabilitiesResponse struct {
	// PEF Version (BCD encoded, LSN first. 51h version 1.5)
	PEFVersion uint8

	SupportOEMEventFilter      bool
	SupportDiagnosticInterrupt bool
	SupportOEMAction           bool
	SupportPowerCycle          bool
	SupportReset               bool
	SupportPowerDown           bool
	SupportAlert               bool

	EventFilterTableEntries uint8
}

func (*GetPEFCapabilitiesResponse) Format

func (res *GetPEFCapabilitiesResponse) Format() string

func (*GetPEFCapabilitiesResponse) Unpack

func (res *GetPEFCapabilitiesResponse) Unpack(msg []byte) error

type GetPEFConfigParamRequest

type GetPEFConfigParamRequest struct {
	// [7] - 1b = get parameter revision only. 0b = get parameter
	// [6:0] - Parameter selector
	GetParamRevisionOnly bool
	ParamSelector        types.PEFConfigParamSelector

	SetSelector   uint8 // 00h if parameter does not require a Set Selector
	BlockSelector uint8 // 00h if parameter does not require a block number
}

30.4 Get PEF Configuration Parameters Command

func (*GetPEFConfigParamRequest) Command

func (req *GetPEFConfigParamRequest) Command() types.Command

func (*GetPEFConfigParamRequest) Pack

func (req *GetPEFConfigParamRequest) Pack() []byte

type GetPEFConfigParamResponse

type GetPEFConfigParamResponse struct {
	// Parameter revision.
	//
	// Format:
	//  - MSN = present revision.
	//  - LSN = oldest revision parameter is backward compatible with.
	//  - 11h for parameters in this specification.
	ParamRevision uint8

	// ParamData not returned when GetParamRevisionOnly is true
	ParamData []byte
}

func (*GetPEFConfigParamResponse) Format

func (res *GetPEFConfigParamResponse) Format() string

func (*GetPEFConfigParamResponse) Unpack

func (res *GetPEFConfigParamResponse) Unpack(msg []byte) error

type GetSensorEventEnableRequest

type GetSensorEventEnableRequest struct {
	SensorNumber uint8
}

35.11 Get Sensor Event Enable Command

func (*GetSensorEventEnableRequest) Command

func (req *GetSensorEventEnableRequest) Command() types.Command

func (*GetSensorEventEnableRequest) Pack

func (req *GetSensorEventEnableRequest) Pack() []byte

type GetSensorEventEnableResponse

type GetSensorEventEnableResponse struct {
	EventMessagesDisabled  bool
	SensorScanningDisabled bool
	types.SensorEventFlag
}

For event , true means the event has enabled.

func (*GetSensorEventEnableResponse) Format

func (res *GetSensorEventEnableResponse) Format() string

func (*GetSensorEventEnableResponse) Unpack

func (res *GetSensorEventEnableResponse) Unpack(msg []byte) error

type GetSensorEventStatusRequest

type GetSensorEventStatusRequest struct {
	SensorNumber uint8
}

35.13 Get Sensor Event Status Command

func (*GetSensorEventStatusRequest) Command

func (req *GetSensorEventStatusRequest) Command() types.Command

func (*GetSensorEventStatusRequest) Pack

func (req *GetSensorEventStatusRequest) Pack() []byte

type GetSensorEventStatusResponse

type GetSensorEventStatusResponse struct {
	EventMessagesDisabled  bool
	SensorScanningDisabled bool
	ReadingUnavailable     bool
	types.SensorEventFlag
}

For event boolean value, true means the event has occurred.

func (*GetSensorEventStatusResponse) Format

func (res *GetSensorEventStatusResponse) Format() string

func (*GetSensorEventStatusResponse) Unpack

func (res *GetSensorEventStatusResponse) Unpack(msg []byte) error

type GetSensorHysteresisRequest

type GetSensorHysteresisRequest struct {
	SensorNumber uint8
}

35.7 Get Sensor Hysteresis Command. Retrieves present hysteresis values for the sensor. Fixed hysteresis values may also be obtained from the sensor SDR.

func (*GetSensorHysteresisRequest) Command

func (req *GetSensorHysteresisRequest) Command() types.Command

func (*GetSensorHysteresisRequest) Pack

func (req *GetSensorHysteresisRequest) Pack() []byte

type GetSensorHysteresisResponse

type GetSensorHysteresisResponse struct {
	PositiveRaw uint8
	NegativeRaw uint8
}

func (*GetSensorHysteresisResponse) Format

func (res *GetSensorHysteresisResponse) Format() string

func (*GetSensorHysteresisResponse) Unpack

func (res *GetSensorHysteresisResponse) Unpack(msg []byte) error

type GetSensorReadingFactorsRequest

type GetSensorReadingFactorsRequest struct {
	SensorNumber uint8
	Reading      uint8
}

35.5 Get Sensor Reading Factors Command. Returns Sensor Reading Factors fields for the specified reading value on the specified sensor.

func (*GetSensorReadingFactorsRequest) Command

func (*GetSensorReadingFactorsRequest) Pack

func (req *GetSensorReadingFactorsRequest) Pack() []byte

type GetSensorReadingFactorsResponse

type GetSensorReadingFactorsResponse struct {
	NextReading uint8
	types.ReadingFactors
}

func (*GetSensorReadingFactorsResponse) Format

func (*GetSensorReadingFactorsResponse) Unpack

func (res *GetSensorReadingFactorsResponse) Unpack(msg []byte) error

type GetSensorReadingRequest

type GetSensorReadingRequest struct {
	SensorNumber uint8
}

35.14 Get Sensor Reading Command

Retrieve a raw sensor reading (current reading) from ipmb

func (*GetSensorReadingRequest) Command

func (req *GetSensorReadingRequest) Command() types.Command

func (*GetSensorReadingRequest) Pack

func (req *GetSensorReadingRequest) Pack() []byte

type GetSensorReadingResponse

type GetSensorReadingResponse struct {
	// reading byte. Ignore on read if sensor does not return an numeric (analog) reading
	Reading uint8

	EventMessagesDisabled bool

	// see 16.5 System Software use of Sensor Scanning bits & Entity Info
	//
	// System software must ignore any sensor that has the sensor scanning bit disabled - if system software didn't disable the sensor.
	SensorScanningDisabled bool

	ReadingUnavailable bool // Software should use this bit to avoid getting an incorrect status while the first sensor update is in progress.

	Above_UNR bool // at or above UNR threshold
	Above_UCR bool // at or above UCR threshold
	Above_UNC bool // at or above UNC threshold
	Below_LNR bool // at or below LNR threshold
	Below_LCR bool // at or below LCR threshold
	Below_LNC bool // at or below LNC threshold

	// see 42.1
	// (Sensor Classes: Discrete)
	// It is possible for a discrete sensor to have more than one state active at a time.
	ActiveStates types.Mask_DiscreteEvent

	OptionalData1 uint8
	OptionalData2 uint8
}

func (*GetSensorReadingResponse) Format

func (res *GetSensorReadingResponse) Format() string

func (*GetSensorReadingResponse) ThresholdStatus

ThresholdStatus returns the threshold status of the sensor, that is, the most severe threshold the reading has crossed. A reading beyond a non-recoverable threshold is normally reported as being beyond the critical and non-critical ones as well, so the checks are ordered from the most severe to the least.

func (*GetSensorReadingResponse) Unpack

func (res *GetSensorReadingResponse) Unpack(msg []byte) error

type GetSensorThresholdsRequest

type GetSensorThresholdsRequest struct {
	SensorNumber uint8
}

35.9 Get Sensor Thresholds Command. Retrieves thresholds for the given sensor.

func (*GetSensorThresholdsRequest) Command

func (req *GetSensorThresholdsRequest) Command() types.Command

func (*GetSensorThresholdsRequest) Pack

func (req *GetSensorThresholdsRequest) Pack() []byte

type GetSensorThresholdsResponse

type GetSensorThresholdsResponse struct {
	// Readable thresholds mask
	UNR_Readable bool
	UCR_Readable bool
	UNC_Readable bool
	LNR_Readable bool
	LCR_Readable bool
	LNC_Readable bool

	// Threshold value
	LNC_Raw uint8
	LCR_Raw uint8
	LNR_Raw uint8
	UNC_Raw uint8
	UCR_Raw uint8
	UNR_Raw uint8
}

func (*GetSensorThresholdsResponse) Format

func (res *GetSensorThresholdsResponse) Format() string

func (*GetSensorThresholdsResponse) Unpack

func (res *GetSensorThresholdsResponse) Unpack(msg []byte) error

type GetSensorTypeRequest

type GetSensorTypeRequest struct {
	SensorNumber uint8
}

GetSensorTypeRequest (see [IPMI specification v2.0], section 35.16)

func (*GetSensorTypeRequest) Command

func (req *GetSensorTypeRequest) Command() types.Command

func (*GetSensorTypeRequest) Pack

func (req *GetSensorTypeRequest) Pack() []byte

type GetSensorTypeResponse

type GetSensorTypeResponse struct {
	SensorType       types.SensorType
	EventReadingType types.EventReadingType
}

func (*GetSensorTypeResponse) Format

func (res *GetSensorTypeResponse) Format() string

func (*GetSensorTypeResponse) Unpack

func (res *GetSensorTypeResponse) Unpack(msg []byte) error

type PETAcknowledgeRequest

type PETAcknowledgeRequest struct {
	SequenceNumber  uint16
	LocalTimestamp  uint32
	EventSourceType uint8
	SensorDevice    uint8
	SensorNumber    uint8
	EventData       types.EventData
}

func (*PETAcknowledgeRequest) Command

func (req *PETAcknowledgeRequest) Command() types.Command

func (*PETAcknowledgeRequest) Pack

func (req *PETAcknowledgeRequest) Pack() []byte

func (*PETAcknowledgeRequest) Unpack

func (req *PETAcknowledgeRequest) Unpack(data []byte) error

type PETAcknowledgeResponse

type PETAcknowledgeResponse struct {
	PETAcknowledgeStatus uint8
}

func (*PETAcknowledgeResponse) Format

func (res *PETAcknowledgeResponse) Format() string

func (*PETAcknowledgeResponse) Pack

func (res *PETAcknowledgeResponse) Pack() []byte

func (*PETAcknowledgeResponse) Unpack

func (res *PETAcknowledgeResponse) Unpack(msg []byte) error

type PlatformEventMessageRequest

type PlatformEventMessageRequest struct {
	// The Generator ID field is a required element of an Event Request Message.
	// This field identifies the device that has generated the Event Message.
	// This is the 7-bit Requester's Slave Address (RqSA) and 2-bit Requester's LUN (RqLUN)
	// if the message was received from the IPMB, or the 7-bit System Software ID
	// if the message was received from system software.
	//
	// For IPMB messages, this field is equated to the Requester's Slave Address and LUN fields.
	// Thus, the Generator ID information is not carried in the data field of an IPMB request message.
	//
	// For 'system side' interfaces, it is not as useful or appropriate to 'overlay' the Generator ID field
	// with the message source address information, and so it is specified as being carried in the data field of the request.
	GeneratorID  uint8
	EvMRev       uint8
	SensorType   uint8
	SensorNumber uint8
	EventDir     types.EventDir
	EventType    types.EventReadingType
	EventData    types.EventData
}

func (*PlatformEventMessageRequest) Command

func (req *PlatformEventMessageRequest) Command() types.Command

func (*PlatformEventMessageRequest) Pack

func (req *PlatformEventMessageRequest) Pack() []byte

type PlatformEventMessageResponse

type PlatformEventMessageResponse struct {
}

func (*PlatformEventMessageResponse) Format

func (res *PlatformEventMessageResponse) Format() string

func (*PlatformEventMessageResponse) Unpack

func (res *PlatformEventMessageResponse) Unpack(msg []byte) error

type ReadEventMessageBufferRequest

type ReadEventMessageBufferRequest struct {
}

func (ReadEventMessageBufferRequest) Command

func (*ReadEventMessageBufferRequest) Pack

func (req *ReadEventMessageBufferRequest) Pack() []byte

type ReadEventMessageBufferResponse

type ReadEventMessageBufferResponse struct {
	// 16 bytes of data in SEL Record format
	MessageData [16]byte
}

func (*ReadEventMessageBufferResponse) Format

func (res *ReadEventMessageBufferResponse) Format() string

func (*ReadEventMessageBufferResponse) Unpack

func (res *ReadEventMessageBufferResponse) Unpack(msg []byte) error

type RearmSensorEventsRequest

type RearmSensorEventsRequest struct {
	SensorNumber uint8

	RearmAllEventStatus bool

	DiscreteEvents bool
	types.
		SensorEventFlag
}

35.12 Re-arm Sensor Events Command

func (*RearmSensorEventsRequest) Command

func (req *RearmSensorEventsRequest) Command() types.Command

func (*RearmSensorEventsRequest) Pack

func (req *RearmSensorEventsRequest) Pack() []byte

type RearmSensorEventsResponse

type RearmSensorEventsResponse struct {
}

func (*RearmSensorEventsResponse) Format

func (res *RearmSensorEventsResponse) Format() string

func (*RearmSensorEventsResponse) Unpack

func (res *RearmSensorEventsResponse) Unpack(msg []byte) error

type SetBMCGlobalEnablesRequest

type SetBMCGlobalEnablesRequest struct {
	// Generic system mgmt. software must do a "read-modify-write" using the Get BMC Global Enables and Set BMC Global Enables to avoid altering EnableOEM_X field.
	EnableOEM2 bool
	EnableOEM1 bool
	EnableOEM0 bool

	EnableSystemEventLogging              bool
	EnableEventMessageBuffer              bool
	EnableEventMessageBufferFullInterrupt bool
	EnableReceiveMessageQueueInterrupt    bool
}

22.1 Set BMC Global Enables Command

func (*SetBMCGlobalEnablesRequest) Command

func (req *SetBMCGlobalEnablesRequest) Command() types.Command

func (*SetBMCGlobalEnablesRequest) Pack

func (req *SetBMCGlobalEnablesRequest) Pack() []byte

type SetBMCGlobalEnablesResponse

type SetBMCGlobalEnablesResponse struct {
}

func (*SetBMCGlobalEnablesResponse) Format

func (res *SetBMCGlobalEnablesResponse) Format() string

func (*SetBMCGlobalEnablesResponse) Unpack

func (res *SetBMCGlobalEnablesResponse) Unpack(msg []byte) error

type SetEventReceiverRequest

type SetEventReceiverRequest struct {
	// Event Receiver Slave Address.
	//  - 0FFh disables Event Message Generation, Otherwise:
	//  - [7:1] - IPMB (I2C) Slave Address
	//  - [0] - always 0b when [7:1] hold I2C slave address
	SlaveAddress uint8
	// [1:0] - Event Receiver LUN
	LUN uint8
}

func (*SetEventReceiverRequest) Command

func (req *SetEventReceiverRequest) Command() types.Command

func (*SetEventReceiverRequest) Pack

func (req *SetEventReceiverRequest) Pack() []byte

type SetEventReceiverResponse

type SetEventReceiverResponse struct {
}

func (*SetEventReceiverResponse) Format

func (res *SetEventReceiverResponse) Format() string

func (*SetEventReceiverResponse) Unpack

func (res *SetEventReceiverResponse) Unpack(msg []byte) error

type SetLastProcessedEventIdRequest

type SetLastProcessedEventIdRequest struct {
	// 0b = set Record ID for last record processed by software.
	// 1b = set Record ID for last record processed by BMC.
	ByBMC    bool
	RecordID uint16
}

func (*SetLastProcessedEventIdRequest) Command

func (*SetLastProcessedEventIdRequest) Pack

func (req *SetLastProcessedEventIdRequest) Pack() []byte

type SetLastProcessedEventIdResponse

type SetLastProcessedEventIdResponse struct {
}

func (*SetLastProcessedEventIdResponse) Format

func (*SetLastProcessedEventIdResponse) Unpack

func (res *SetLastProcessedEventIdResponse) Unpack(msg []byte) error

type SetPEFConfigParamRequest

type SetPEFConfigParamRequest struct {
	ParamSelector types.PEFConfigParamSelector
	ParamData     []byte
}

func (*SetPEFConfigParamRequest) Command

func (req *SetPEFConfigParamRequest) Command() types.Command

func (*SetPEFConfigParamRequest) Pack

func (req *SetPEFConfigParamRequest) Pack() []byte

type SetPEFConfigParamResponse

type SetPEFConfigParamResponse struct {
}

func (*SetPEFConfigParamResponse) Format

func (res *SetPEFConfigParamResponse) Format() string

func (*SetPEFConfigParamResponse) Unpack

func (res *SetPEFConfigParamResponse) Unpack(msg []byte) error

type SetSensorEventEnableMode

type SetSensorEventEnableMode uint8
const (
	SetSensorEventEnableModeNoChange SetSensorEventEnableMode = 0
	SetSensorEventEnableModeEnable   SetSensorEventEnableMode = 1
	SetSensorEventEnableModeDisable  SetSensorEventEnableMode = 2
)

type SetSensorEventEnableRequest

type SetSensorEventEnableRequest struct {
	SensorNumber uint8

	DisableEventMessages  bool
	DisableSensorScanning bool

	Mode SetSensorEventEnableMode

	DiscreteEvents bool
	types.
		SensorEventFlag
}

35.10 Set Sensor Event Enable Command

func (*SetSensorEventEnableRequest) Command

func (req *SetSensorEventEnableRequest) Command() types.Command

func (*SetSensorEventEnableRequest) Pack

func (req *SetSensorEventEnableRequest) Pack() []byte

type SetSensorEventEnableResponse

type SetSensorEventEnableResponse struct {
}

func (*SetSensorEventEnableResponse) Format

func (res *SetSensorEventEnableResponse) Format() string

func (*SetSensorEventEnableResponse) Unpack

func (res *SetSensorEventEnableResponse) Unpack(msg []byte) error

type SetSensorHysteresisRequest

type SetSensorHysteresisRequest struct {
	SensorNumber       uint8
	PositiveHysteresis uint8
	NegativeHysteresis uint8
}

func (*SetSensorHysteresisRequest) Command

func (req *SetSensorHysteresisRequest) Command() types.Command

func (*SetSensorHysteresisRequest) Pack

func (req *SetSensorHysteresisRequest) Pack() []byte

type SetSensorHysteresisResponse

type SetSensorHysteresisResponse struct {
}

func (*SetSensorHysteresisResponse) Format

func (res *SetSensorHysteresisResponse) Format() string

func (*SetSensorHysteresisResponse) Unpack

func (res *SetSensorHysteresisResponse) Unpack(msg []byte) error

type SetSensorReadingAndEventStatusRequest

type SetSensorReadingAndEventStatusRequest struct {
	SensorNumber uint8

	EventDataBytesOperation  uint8
	AssertionBitsOperation   uint8
	DeassertionBitsOperation uint8
	SensorReadingOperation   uint8

	SensorReading uint8
	types.SensorEventFlag

	EventData1 uint8
	EventData2 uint8
	EventData3 uint8
}

func (*SetSensorReadingAndEventStatusRequest) Command

func (*SetSensorReadingAndEventStatusRequest) Pack

type SetSensorReadingAndEventStatusResponse

type SetSensorReadingAndEventStatusResponse struct {
}

func (*SetSensorReadingAndEventStatusResponse) Format

func (*SetSensorReadingAndEventStatusResponse) Unpack

type SetSensorThresholdsRequest

type SetSensorThresholdsRequest struct {
	SensorNumber uint8

	// Set Threshold flag
	SetUNR bool
	SetUCR bool
	SetUNC bool
	SetLNR bool
	SetLCR bool
	SetLNC bool

	// Threshold value
	LNC_Raw uint8
	LCR_Raw uint8
	LNR_Raw uint8
	UNC_Raw uint8
	UCR_Raw uint8
	UNR_Raw uint8
}

35.8 Set Sensor Thresholds Command. Note that the application issuing this command is responsible for ensuring thresholds are set in the proper order (e.g. upper critical above upper non-critical):

Upper Non Recoverable area
-----------------UNR threshold
Upper Critical area
-----------------UCR threshold
Upper Non Critical area
-----------------UNC threshold
OK area
-----------------LNC threshold
Lower Non Critical area
-----------------LCR threshold
Lower Critical area
-----------------LNR threshold
Lower NonRecoverable area

func (*SetSensorThresholdsRequest) Command

func (req *SetSensorThresholdsRequest) Command() types.Command

func (*SetSensorThresholdsRequest) Pack

func (req *SetSensorThresholdsRequest) Pack() []byte

type SetSensorThresholdsResponse

type SetSensorThresholdsResponse struct {
}

func (*SetSensorThresholdsResponse) Format

func (res *SetSensorThresholdsResponse) Format() string

func (*SetSensorThresholdsResponse) Unpack

func (res *SetSensorThresholdsResponse) Unpack(msg []byte) error

type SetSensorTypeRequest

type SetSensorTypeRequest struct {
	SensorNumber     uint8
	SensorType       types.SensorType
	EventReadingType types.EventReadingType
}

func (*SetSensorTypeRequest) Command

func (req *SetSensorTypeRequest) Command() types.Command

func (*SetSensorTypeRequest) Pack

func (req *SetSensorTypeRequest) Pack() []byte

type SetSensorTypeResponse

type SetSensorTypeResponse struct {
}

func (*SetSensorTypeResponse) Format

func (res *SetSensorTypeResponse) Format() string

func (*SetSensorTypeResponse) Unpack

func (res *SetSensorTypeResponse) Unpack(msg []byte) error

Jump to